def domain_to_star_cert_filename(domain):
    return "_".join(["star"] + domain.split("."))


def create_csr_command(domain, country_code, state, locality, organization):
    """
    Helper to create command for creating csr
    
    Instructions are here:
        https://www.digicert.com/easy-csr/openssl.htm
    """
    filename = domain_to_star_cert_filename(domain)
    
    cmd = 'openssl req -new -newkey rsa:2048 -nodes'
    cmd += ' -out %s.csr -keyout %s.key' % ((filename,) * 2)
    cmd += ' -subj "/C=%s/ST=%s/L=%s/O=%s/CN=*.%s"' % (
        country_code,
        state,
        locality,
        organization,
        domain
    )
    return cmd


def create_self_sign_csr_command(domain):
    """
    Helper to create command to self-sign csr
    """
    filename = domain_to_star_cert_filename(domain)
    cmd = 'openssl x509 -req -days 365'
    cmd += ' -in %s.csr -signkey %s.key -out %s.crt' % ((filename,) * 3)
    return cmd



from datetime import date

ADMIN_USER = 'postgres'
DEFAULT_PORT = 5432
DEFAULT_HOST = '127.0.0.1'


def enter(db_name, options=None):
    return 'psql --host=127.0.0.1 {options} {db_name}'.format(
        db_name=db_name,
        options=' %s ' % options if options else ' ')


def psql(query, host=None, port=None, db_name=None, user=None):
    return 'psql{host}{port}{user}{command}{db_name}'.format(
        host=' --host=%s' % host if host else '',
        port=' --port=%s' % port if port else '',
        user=' --user=%s' % user if user else '',
        command=' --command="%s"' % query,
        db_name=' %s' % db_name if db_name else '')


def psql_from_file(filepath, db_name=None, user=None):
    return 'psql --host=127.0.0.1{user}{db_name} < {filepath}'.format(
        user=' --user=%s' % user if user else '',
        db_name=' %s' % db_name if db_name else '',
        filepath=filepath)


def create_pgpass_line(database, username, password, host='127.0.0.1', port=DEFAULT_PORT):
    return '{host}:{port}:{database}:{username}:{password}'.format(
        host=host,
        database=database,
        port=port,
        username=username,
        password=password)


def backup(db_name, port=DEFAULT_PORT, options=None):
    """
    Backup
    
    --no-owner: exclude permission statements
    --create: include db schema
    """
    return 'pg_dump{host}{port} --no-owner --create{options}{db_name} > {filename}'.format(
        host=' --host=127.0.0.1',
        port=' --port=%s' % port,
        options=' %s ' % options if options else ' ',
        db_name=db_name,
        filename='%s_backup_%s.sql' % (db_name, date.today().isoformat()))


def restore(filepath, db_name=None, options=None):
    return 'pg_restore --host=127.0.0.1{options} {db_name} {filepath}'.format(
        options=' %s' % options if options else '',
        db_name='--dbname=%s' % db_name if db_name else '',
        filepath=filepath)



def get_home_dir(user):
    """
    Get user home dir
    
    NOTE: This could probably have been done nicer. Probably done this way to be able to handle
    non-standard home dir locations.
    """
    return "cd ~%s && pwd" % user



def exists(user):
    return 'getent passwd %s' % user


def add(user):
    return "useradd --create-home --shell /bin/bash %s" % user


def append_to_group(user, groups):
    return 'usermod --append --groups %s %s' % (",".join(groups), user)



def install(packages, release=None):
    return "apt-get -y{release}install {packages}".format(
        release=' -t %s' % release if release else ' ',
        packages=" ".join(packages))


def import_apt_key_from_url(url):
    """
    Import a GPG key for a repository into apt's keychain from given url
    """
    return 'wget -qO - {url} | apt-key add -'.format(url=url)


def repo_sources_line(uri, distro, components):
    return "deb {uri} {distro} {components}".format(
        uri=uri,
        distro=distro,
        components=components)


def update():
    """
    Update package index
    """
    return "apt-get update"



# -*- coding: utf-8 -*-

from setuptools import setup


def readme():
    with open('README.rst') as f:
        return f.read()


setup(
    name='tol',
    version='0.0.8',
    packages=['tol'],
    author='Øystein S. Haaland',
    author_email='oystein@beat.no',
    description="tøl n1 (norrønt tól 'reiskap') kollektivt: (små)saker",
    long_description=readme(),
    url='https://github.com/beat-no/tol'
)



def mkdir(path, mode=None):
    return 'mkdir --parents {mode} {path}'.format(
        path=path,
        mode='--mode %s' % mode if mode else '')


def chown(user, path):
    return 'chown --recursive %s:%s %s' % (user, user, path)


def exists(path):
    return "test -e %s" % path
